import { SvelteComponentTyped } from "svelte";
import type { NavbarType } from '../types';
declare const __propDef: {
    props: {
        liButtonClass?: string | undefined;
        name: string;
        child?: NavbarType[] | undefined;
        dropdownDiv?: string | undefined;
        dropdownLinkClassWithChild?: string | undefined;
        rel?: string | undefined;
    };
    events: {
        blur: FocusEvent;
        change: Event;
        click: MouseEvent;
        focus: FocusEvent;
        keydown: KeyboardEvent;
        keypress: KeyboardEvent;
        keyup: KeyboardEvent;
        mouseenter: MouseEvent;
        mouseleave: MouseEvent;
        mouseover: MouseEvent;
    } & {
        [evt: string]: CustomEvent<any>;
    };
    slots: {
        default: {};
    };
};
export type NavDropdownProps = typeof __propDef.props;
export type NavDropdownEvents = typeof __propDef.events;
export type NavDropdownSlots = typeof __propDef.slots;
/**
 * [Go to Navbar](https://flowbite-svelte.com/docs/components/navbar)
 * ## Props
 * @prop liButtonClass: string = 'flex items-center justify-between w-full';
 * @prop name: string;
 * @prop child: NavbarType[] = [];
 * @prop dropdownDiv: string = '';
 * @prop dropdownLinkClassWithChild: string | undefined = undefined;
 * @prop rel: string | undefined = undefined;
 * ## Event
 * - on:blur
 * - on:change
 * - on:click
 * - on:focus
 * - on:keydown
 * - on:keypress
 * - on:keyup
 * - on:mouseenter
 * - on:mouseleave
 * - on:mouseover
 * ## Example
 * ```
 * <script>
 *   import { Navbar, NavBrand, NavLi, NavUl, NavHamburger } from 'flowbite-svelte'
 * </script>
 *
 * <Navbar let:hidden let:toggle>
 *   <NavBrand href="/">
 *     <img
 *       src="/images/flowbite-svelte-icon-logo.svg"
 *       class="mr-3 h-6 sm:h-9"
 *       alt="Flowbite Logo"
 *     />
 *     <span class="self-center whitespace-nowrap text-xl font-semibold dark:text-white">
 *       Flowbite
 *     </span>
 *   </NavBrand>
 *   <NavHamburger on:click={toggle} />
 *   <NavUl {hidden}>
 *     <NavLi href="/" active={true}>Home</NavLi>
 *     <NavLi href="/about">About</NavLi>
 *     <NavLi href="/services">Services</NavLi>
 *     <NavLi href="/pricing">Pricing</NavLi>
 *     <NavLi href="/contact">Contact</NavLi>
 *   </NavUl>
 * </Navbar>
 * ```
 */
export default class NavDropdown extends SvelteComponentTyped<NavDropdownProps, NavDropdownEvents, NavDropdownSlots> {
}
export {};
//# sourceMappingURL=NavDropdown.svelte.d.ts.map